/**
 * @module botframework-connector
 */
import { ConfidentialClientApplication } from '@azure/msal-node';
import { ServiceClientCredentials } from '@azure/core-http';
import { ServiceClientCredentialsFactory } from './serviceClientCredentialsFactory';
/**
 * An implementation of ServiceClientCredentialsFactory that generates MsalAppCredentials
 */
export declare class MsalServiceClientCredentialsFactory implements ServiceClientCredentialsFactory {
    private readonly clientApplication;
    private readonly appId;
    /**
     * Create an MsalServiceClientCredentialsFactory instance using runtime configuration and an
     * `@azure/msal-node` `ConfidentialClientApplication`.
     *
     * @param appId App ID for validation.
     * @param clientApplication An `@azure/msal-node` `ConfidentialClientApplication` instance.
     */
    constructor(appId: string, clientApplication: ConfidentialClientApplication);
    /**
     * @inheritdoc
     */
    isValidAppId(appId: string): Promise<boolean>;
    /**
     * @inheritdoc
     */
    isAuthenticationDisabled(): Promise<boolean>;
    /**
     * @inheritdoc
     */
    createCredentials(appId: string, audience: string, loginEndpoint: string, _validateAuthority: boolean): Promise<ServiceClientCredentials>;
}
//# sourceMappingURL=msalServiceClientCredentialsFactory.d.ts.map
