/**
 * @module botframework-connector
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { ProxySettings } from '@azure/core-http';
/**
 * Class in charge of manage OpenId metadata.
 */
export declare class OpenIdMetadata {
    private url;
    private proxySettings?;
    private lastUpdated;
    private keys;
    /**
     * Initializes a new instance of the [OpenIdMetadata](xref:botframework-connector.OpenIdMetadata) class.
     *
     * @param url Metadata Url.
     * @param proxySettings The proxy settings for the request.
     */
    constructor(url: string, proxySettings?: ProxySettings);
    /**
     * Gets the Signing key.
     *
     * @param keyId The key ID to search for.
     * @returns A `Promise` representation for either a [IOpenIdMetadataKey](botframework-connector:module.IOpenIdMetadataKey) or `null`.
     */
    getKey(keyId: string): Promise<IOpenIdMetadataKey | null>;
    /**
     * @private
     */
    private refreshCache;
    /**
     * @private
     */
    private findKey;
}
export interface IOpenIdMetadataKey {
    key: string;
    endorsements?: string[];
}
//# sourceMappingURL=openIdMetadata.d.ts.map