/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { RequestOptionsBase, ServiceCallback } from "@azure/core-http";
import { ConnectorClientContext } from "../connectorClientContext";
import * as Models from "../models";
/** Class representing a Attachments. */
export declare class Attachments {
    private readonly client;
    /**
     * Create a Attachments.
     * @param {ConnectorClientContext} client Reference to the service client.
     */
    constructor(client: ConnectorClientContext);
    /**
     * Get AttachmentInfo structure describing the attachment views
     * @summary GetAttachmentInfo
     * @param attachmentId attachment id
     * @param [options] The optional parameters
     * @returns Promise<Models.AttachmentsGetAttachmentInfoResponse>
     */
    getAttachmentInfo(attachmentId: string, options?: RequestOptionsBase): Promise<Models.AttachmentsGetAttachmentInfoResponse>;
    /**
     * @param attachmentId attachment id
     * @param callback The callback
     */
    getAttachmentInfo(attachmentId: string, callback: ServiceCallback<Models.AttachmentInfo>): void;
    /**
     * @param attachmentId attachment id
     * @param options The optional parameters
     * @param callback The callback
     */
    getAttachmentInfo(attachmentId: string, options: RequestOptionsBase, callback: ServiceCallback<Models.AttachmentInfo>): void;
    /**
     * Get the named view as binary content
     * @summary GetAttachment
     * @param attachmentId attachment id
     * @param viewId View id from attachmentInfo
     * @param [options] The optional parameters
     * @returns Promise<Models.AttachmentsGetAttachmentResponse>
     */
    getAttachment(attachmentId: string, viewId: string, options?: RequestOptionsBase): Promise<Models.AttachmentsGetAttachmentResponse>;
    /**
     * @param attachmentId attachment id
     * @param viewId View id from attachmentInfo
     * @param callback The callback
     */
    getAttachment(attachmentId: string, viewId: string, callback: ServiceCallback<void>): void;
    /**
     * @param attachmentId attachment id
     * @param viewId View id from attachmentInfo
     * @param options The optional parameters
     * @param callback The callback
     */
    getAttachment(attachmentId: string, viewId: string, options: RequestOptionsBase, callback: ServiceCallback<void>): void;
}
//# sourceMappingURL=attachments.d.ts.map